==> nextcloud-app-mail-1.11.0-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fa.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "شناسایی خودکار با شکست مواجه شد. لطفا از حالت دستی استفاده کنید.",
    "Updating account failed: " : "به روزرسانی حساب انجام نشد:",
    "Creating account failed: " : "ایجاد حساب کاربری انجام نشد:",
    "Embedded message %s" : "پیام درج شده%s",
    "Important mail" : "ایمیل‌های مهم",
    "Mails" : "ایمیل‌ها",
    "Mail" : "ایمیل",
    "💌 A mail app for Nextcloud" : "یک برنامه نامه پستی برای Nextcloud",
    "Auto" : "خودکار",
    "Name" : "نام",
    "Mail Address" : "آدرس رایانامه",
    "Password" : "گذرواژه",
    "Manual" : "کتابچه راهنمای",
    "IMAP Settings" : "تنظیمات IMAP",
    "IMAP Host" : "میزبان IMAP",
    "IMAP Security" : "امنیت IMAP",
    "None" : "هیچ‌کدام",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "شروع TLS",
    "IMAP Port" : "پرت IMAP",
    "IMAP User" : "کاربر IMAP",
    "IMAP Password" : "گذرواژه IMAP",
    "SMTP Settings" : "تنظیمات SMTP",
    "SMTP Host" : "میزبان SMTP",
    "SMTP Security" : "امنیت SMTP",
    "SMTP Port" : "درگاه SMTP",
    "SMTP User" : "کاربر SMTP",
    "SMTP Password" : "رمز عبور SMTP",
    "Save" : "ذخیره",
    "Connect" : "اتصال",
    "Account settings" : "تنظیمات حساب",
    "Change name" : "تغییر نام",
    "Signature" : "امضا",
    "A signature is added to the text of new messages and replies." : "یک امضا به متن پیامها و پاسخ های جدید اضافه می شود.",
    "Writing mode" : "حالت نوشتن",
    "Preferred writing mode for new messages and replies." : "حالت نوشتن برای پیام ها و پاسخ های جدید ترجیح داده شده است.",
    "Mail server" : "سرور پست الکترونیکی",
    "Cancel" : "لغو",
    "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
    "From" : "از",
    "Select account" : "حساب را انتخاب کنید",
    "To" : "به",
    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
    "No contacts found." : "هیچ تماسی یافت نشد.",
    "Subject" : "موضوع",
    "Subject …" : "موضوع …",
    "This message came from a noreply address so your reply will probably not be read." : "این پیام از یک آدرس خیلی روشن آمده است بنابراین پاسخ شما احتمالاً خوانده نمی شود.",
    "Write message …" : "ارسال پیام ...",
    "Saving draft …" : "در حال ذخیره پیش نویس ...",
    "Draft saved" : "پیش نویس ذخیره شد",
    "Upload attachment" : "پیوست را بارگیری کنید",
    "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
    "Enable formatting" : "قالب بندی را فعال کنید",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "آیا به دنبال راهی برای رمزگذاری ایمیل های خود هستید؟ افزونه مرورگر Mailvelope را نصب کنید!",
    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
    "Sending …" : "در حال ارسال ...",
    "Error sending your message" : "خطایی در ارسال پیام شما",
    "Go back" : "برگرد",
    "Retry" : "تلاش دوباره",
    "Message sent!" : "پیام ارسال شد!",
    "Write another message" : "پیام دیگری بنویسید",
    "Send" : "ارسال",
    "Uploading {percent}% …" : "در حال بارگیری {درصد… ...",
    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
    "Plain text" : "متن ساده",
    "Rich text" : "متن غنی",
    "Draft: " : "پیش نویس:",
    "Mark unread" : "علامت گذاری به عنوان خوانده نشده",
    "Mark read" : "علامت گذاری به عنوان خوانده شده",
    "Unselect" : "لغو انتخاب",
    "Select" : "انتخاب",
    "Blind copy recipients only" : "فقط گیرندگان کپی کور",
    "Report this bug" : "گزارش این اشکال",
    "Could not create event" : "رویداد ایجاد نشد",
    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
    "Loading messages" : "بارگیری پیام ها",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
    "Choose" : "انتخاب کنید",
    "Favorites" : "علاقه مندی ها",
    "Other" : "دیگر",
    "Reply" : "پاسخ",
    "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
    "Forward" : "فرستادن",
    "Import into calendar" : "وارد تقویم شوید",
    "Download attachment" : "پیوست را بارگیری کنید",
    "Save to Files" : "ذخیره در پرونده ها",
    "Unnamed" : "بی نام",
    "Embedded message" : "پیام درج شده",
    "Choose a folder to store the attachment in" : "لطفا پوشه ای را برای ذخیره سازی ضمیمه انتخاب کنید",
    "Save all to Files" : "ذخیره همه در پرونده ها",
    "Choose a folder to store the attachments in" : "پوشه ای را برای ذخیره کردن پیوست ها انتخاب کنید",
    "The images have been blocked to protect your privacy." : "تصاویر برای محافظت از حریم خصوصی شما مسدود شده اند.",
    "Move" : "انتقال",
    "New message" : "پیام جدید",
    "Settings" : "تنظیمات",
    "Quota" : "سهم",
    "Saving" : "درحال ذخیره",
    "Move down" : "حرکت به پایین",
    "Remove account" : "حذف حساب کاربری",
    "Loading …" : "بارگذاری …",
    "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
    "Edit name" : "ویرایش نام",
    "Clear cache" : "پاک‌سازی انباره",
    "Not found" : "پیدا نشد",
    "Could not load your draft" : "پیش نویس شما بارگیری نمی شود",
    "Could not load original message" : "پیام اصلی بارگیری نشد",
    "No message selected" : "پیامی انتخاب نشده است",
    "Signature …" : "امضا ...",
    "Save signature" : "ذخیره امضا",
    "Delete" : "حذف",
    "Import into {calendar}" : "{وارد {تقویم",
    "Event imported into {calendar}" : "{رویداد وارد شده به {تقویم",
    "Airplane" : "هواپیما",
    "Reservation {id}" : "رزرو {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
    "Train" : "رشته",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
    "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
    "Mail app" : "برنامه پست الکترونیکی",
    "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
    "Email: {email}" : "ایمیل: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}: {port} (رمزگذاری s ssl))",
    "General" : "عمومی",
    "IMAP" : "IMAP",
    "User" : "User",
    "Host" : "میزبان",
    "Port" : "درگاه",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
    "Keyboard shortcut" : "صفحه کلید",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Speed up your Mail experience with these quick shortcuts." : "تجربه ایمیل خود را با این میانبرهای سریع سرعت بخشید.",
    "Compose new message" : "نوشتن پیام جدید",
    "Newer message" : "پیام جدیدتر",
    "Older message" : "پیام قدیمی تر",
    "Toggle star" : "تعویض ستاره",
    "Toggle unread" : "تغییر حالت خوانده نشده",
    "Search" : "جستجو",
    "Refresh" : "تازه‌سازی",
    "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
    "Unexpected error during account creation" : "خطای غیر منتظره هنگام ایجاد حساب",
    "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
    "All" : "همه",
    "Archive" : "آرشیو",
    "Drafts" : "پیش نویس",
    "All inboxes" : "همه صندوق ورودی",
    "Inbox" : "صندوق ورودی",
    "Junk" : "آشغال",
    "Sent" : "ارسال شده",
    "Trash" : "زباله ها",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "ایمیل Nextclould",
    "Could not load {tag}{name}{endtag}" : "بارگیری {برچسب} {نام} {endtag ould} بارگیری نشد",
    "There was a problem loading {tag}{name}{endtag}" : "هنگام بارگیری {tag} {name} {endtag } مشکلی رخ داد",
    "Could not load your message" : "پیام شما بارگیری نشد",
    "Could not load the desired message" : "پیام مورد نظر بارگیری نشد",
    "Could not load the message" : "بارگیری پیام امکان پذیر نیست",
    "Error loading message" : "خطا در بارگزاری پیام",
    "Forwarding to %s" : "انتقال به%s",
    "Click here if you are not automatically redirected within the next few seconds." : "اگر چند ثانیه دیگر به طور خودکار هدایت نشود ، اینجا را کلیک کنید.",
    "Redirect" : "تغییر مسیر",
    "The link leads to %s" : "پیوند منجر به%s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "اگر مایل به بازدید از آن صفحه نیستید ، می توانید به <a href=\"%s\">ایمیل</a> برگردید.",
    "Continue to %s" : "ادامه دهید%s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-1.13.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fa.js <==
OC.L10N.register(
    "mail",
    {
    "Auto detect failed. Please use manual mode." : "شناسایی خودکار با شکست مواجه شد. لطفا از حالت دستی استفاده کنید.",
    "Updating account failed: " : "به روزرسانی حساب انجام نشد:",
    "Embedded message %s" : "پیام درج شده%s",
    "Important mail" : "ایمیل‌های مهم",
    "Important" : "مهم",
    "Work" : "کار",
    "Personal" : "شخصی",
    "Later" : "بعدا",
    "Mails" : "ایمیل‌ها",
    "Mail" : "ایمیل",
    "💌 A mail app for Nextcloud" : "یک برنامه نامه پستی برای Nextcloud",
    "Auto" : "خودکار",
    "Name" : "نام",
    "Password" : "گذرواژه",
    "Manual" : "کتابچه راهنمای",
    "IMAP Settings" : "تنظیمات IMAP",
    "IMAP Host" : "میزبان IMAP",
    "IMAP Security" : "امنیت IMAP",
    "None" : "هیچ‌کدام",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "شروع TLS",
    "IMAP Port" : "پرت IMAP",
    "IMAP User" : "کاربر IMAP",
    "IMAP Password" : "گذرواژه IMAP",
    "SMTP Settings" : "تنظیمات SMTP",
    "SMTP Host" : "میزبان SMTP",
    "SMTP Security" : "امنیت SMTP",
    "SMTP Port" : "درگاه SMTP",
    "SMTP User" : "کاربر SMTP",
    "SMTP Password" : "رمز عبور SMTP",
    "Save" : "ذخیره",
    "Connect" : "اتصال",
    "Account settings" : "تنظیمات حساب",
    "Change name" : "تغییر نام",
    "Signature" : "امضا",
    "A signature is added to the text of new messages and replies." : "یک امضا به متن پیامها و پاسخ های جدید اضافه می شود.",
    "Writing mode" : "حالت نوشتن",
    "Preferred writing mode for new messages and replies." : "حالت نوشتن برای پیام ها و پاسخ های جدید ترجیح داده شده است.",
    "Mail server" : "سرور پست الکترونیکی",
    "Email address" : "آدرس ایمیل",
    "Cancel" : "لغو",
    "Add mail account" : "حساب کاربری پست الکترونیکی اضافه کنید",
    "Use Gravatar and favicon avatars" : "از آواتارهای Gravatar و Favicon استفاده کنید",
    "Register as application for mail links" : "به عنوان برنامه برای پیوندهای نامه ثبت نام کنید",
    "From" : "از",
    "Select account" : "حساب را انتخاب کنید",
    "To" : "به",
    "Contact or email address …" : "تماس با یا آدرس ایمیل ...",
    "No contacts found." : "هیچ تماسی یافت نشد.",
    "Subject" : "موضوع",
    "Subject …" : "موضوع …",
    "This message came from a noreply address so your reply will probably not be read." : "این پیام از یک آدرس خیلی روشن آمده است بنابراین پاسخ شما احتمالاً خوانده نمی شود.",
    "Write message …" : "ارسال پیام ...",
    "Saving draft …" : "در حال ذخیره پیش نویس ...",
    "Draft saved" : "پیش نویس ذخیره شد",
    "Upload attachment" : "پیوست را بارگیری کنید",
    "Add attachment from Files" : "پیوست را از پرونده ها اضافه کنید",
    "Enable formatting" : "قالب بندی را فعال کنید",
    "Enter a date" : "تاریخ را وارد کنید",
    "Uploading attachments …" : "درحال بارگذاری پیوستها …",
    "Sending …" : "در حال ارسال ...",
    "Error sending your message" : "خطایی در ارسال پیام شما",
    "Go back" : "برگرد",
    "Retry" : "تلاش دوباره",
    "Message sent!" : "پیام ارسال شد!",
    "Send" : "ارسال",
    "Uploading {percent}% …" : "در حال بارگیری {درصد… ...",
    "Choose a file to add as attachment" : "پرونده ای را برای اضافه کردن به عنوان پیوست انتخاب کنید",
    "Plain text" : "متن ساده",
    "Rich text" : "متن غنی",
    "Draft: " : "پیش نویس:",
    "Unfavorite" : "ناخوشایند",
    "Favorite" : "مورد‌ ‌علاقه‌",
    "Read" : "خواندن",
    "Unselect" : "لغو انتخاب",
    "Select" : "انتخاب",
    "Edit tags" : "ویرایش تگ ها",
    "Move" : "انتقال",
    "More actions" : "اقدامات بیشتر",
    "Blind copy recipients only" : "فقط گیرندگان کپی کور",
    "Report this bug" : "گزارش این اشکال",
    "All day" : "تمام روز",
    "Create" : "ساخت",
    "Could not create event" : "رویداد ایجاد نشد",
    "Could not open mailbox" : "صندوق پستی امکان پذیر نیست",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "نمایه سازی پیام های شما این می تواند کمی برای صندوق های پستی بزرگتر کمی طولانی شود.",
    "Choose" : "انتخاب کنید",
    "Favorites" : "علاقه مندی ها",
    "Other" : "دیگر",
    "Reply" : "پاسخ",
    "Reply to sender only" : "فقط به فرستنده پاسخ دهید",
    "Forward" : "فرستادن",
    "Import into calendar" : "وارد تقویم شوید",
    "Download attachment" : "پیوست را بارگیری کنید",
    "Save to Files" : "ذخیره در پرونده ها",
    "Unnamed" : "بی نام",
    "Embedded message" : "پیام درج شده",
    "Choose a folder to store the attachment in" : "لطفا پوشه ای را برای ذخیره سازی ضمیمه انتخاب کنید",
    "Save all to Files" : "ذخیره همه در پرونده ها",
    "Choose a folder to store the attachments in" : "پوشه ای را برای ذخیره کردن پیوست ها انتخاب کنید",
    "The images have been blocked to protect your privacy." : "تصاویر برای محافظت از حریم خصوصی شما مسدود شده اند.",
    "New message" : "پیام جدید",
    "Settings" : "تنظیمات",
    "Quota" : "سهم",
    "Saving" : "درحال ذخیره",
    "Move down" : "حرکت به پایین",
    "Remove account" : "حذف حساب کاربری",
    "Loading …" : "بارگذاری …",
    "Mark all as read" : "علامت همه به عنوان خوانده‌شده",
    "Edit name" : "ویرایش نام",
    "Clear cache" : "پاک‌سازی انباره",
    "No message selected" : "پیامی انتخاب نشده است",
    "Delete" : "حذف",
    "Copy to clipboard" : "کپی کردن به حافظه موقت",
    "Add" : "افزودن",
    "Disabled" : "غیرفعال شده",
    "Enabled" : "فعال شده",
    "Signature …" : "امضا ...",
    "Save signature" : "ذخیره امضا",
    "Set" : "تنظیم",
    "Unset" : "تنظیم نشده است",
    "Add tag" : "برچسب اضافه کنید",
    "Tag already exists" : "تگ از قبل وجود دارد",
    "Not found" : "پیدا نشد",
    "Remove" : "حذف",
    "Import into {calendar}" : "{وارد {تقویم",
    "Event imported into {calendar}" : "{رویداد وارد شده به {تقویم",
    "Airplane" : "هواپیما",
    "Reservation {id}" : "رزرو {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{پرواز} {پرواز Nr} از {depAirport} به {arrAirport}",
    "Train" : "رشته",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} از {depStation} تا {arrStation}",
    "Train from {depStation} to {arrStation}" : "آموزش از {depStation} تا {arrStation} Train",
    "Mail app" : "برنامه پست الکترونیکی",
    "The mail app allows users to read mails on their IMAP accounts." : "برنامه نامه الکترونیکی به کاربران این امکان را می دهد تا نامه ها را در حساب های IMAP خود بخوانند.",
    "Reset" : "بازنشاندن",
    "Email: {email}" : "ایمیل: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} on {host}: {port} (رمزگذاری {ssl))",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} on {host}: {port} (رمزگذاری s ssl))",
    "General" : "عمومی",
    "IMAP" : "IMAP",
    "User" : "User",
    "Host" : "میزبان",
    "Port" : "درگاه",
    "SMTP" : "SMTP",
    "With the settings above, the app will create account settings in the following way:" : "با تنظیمات فوق ، برنامه تنظیمات حساب را به روش زیر ایجاد می کند:",
    "Keyboard shortcut" : "صفحه کلید",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Speed up your Mail experience with these quick shortcuts." : "تجربه ایمیل خود را با این میانبرهای سریع سرعت بخشید.",
    "Compose new message" : "نوشتن پیام جدید",
    "Newer message" : "پیام جدیدتر",
    "Older message" : "پیام قدیمی تر",
    "Toggle star" : "تعویض ستاره",
    "Toggle unread" : "تغییر حالت خوانده نشده",
    "Search" : "جستجو",
    "Refresh" : "تازه‌سازی",
    "Connect your mail account" : "حساب ایمیل خود را وصل کنید",
    "Itinerary for {type} is not supported yet" : "برنامه سفر برای {نوع yet هنوز پشتیبانی نمی شود",
    "All" : "همه",
    "Archive" : "آرشیو",
    "Drafts" : "پیش نویس",
    "All inboxes" : "همه صندوق ورودی",
    "Inbox" : "صندوق ورودی",
    "Junk" : "آشغال",
    "Sent" : "ارسال شده",
    "Trash" : "زباله ها",
    "{from}\n{subject}" : "{from}\n{subject}",
    "Nextcloud Mail" : "ایمیل Nextclould",
    "Message sent" : "پیام ارسال شد",
    "Could not load {tag}{name}{endtag}" : "بارگیری {برچسب} {نام} {endtag ould} بارگیری نشد",
    "There was a problem loading {tag}{name}{endtag}" : "هنگام بارگیری {tag} {name} {endtag } مشکلی رخ داد",
    "Could not load your message" : "پیام شما بارگیری نشد",
    "Could not load the desired message" : "پیام مورد نظر بارگیری نشد",
    "Could not load the message" : "بارگیری پیام امکان پذیر نیست",
    "Error loading message" : "خطا در بارگزاری پیام",
    "Forwarding to %s" : "انتقال به%s",
    "Click here if you are not automatically redirected within the next few seconds." : "اگر چند ثانیه دیگر به طور خودکار هدایت نشود ، اینجا را کلیک کنید.",
    "Redirect" : "تغییر مسیر",
    "The link leads to %s" : "پیوند منجر به%s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "اگر مایل به بازدید از آن صفحه نیستید ، می توانید به <a href=\"%s\">ایمیل</a> برگردید.",
    "Continue to %s" : "ادامه دهید%s"
},
"nplurals=2; plural=(n > 1);");
